==> wow_views-0.0.59.tar.gz: lib/common/theme/input_decoration_theme.dart <==
import 'package:flutter/material.dart';
import 'package:wow_views/common/color.dart';
import 'package:wow_views/common/text_style.dart';

const InputDecorationTheme bds8xInputDecorationTheme = InputDecorationTheme(
  labelStyle: TextStyle(
    color: Bds8xColor.black,
    fontWeight: FontWeight.bold,
    fontSize: 14,
    overflow: TextOverflow.ellipsis,
  ),
  floatingLabelStyle: TextStyle(
    color: Bds8xColor.black,
    fontWeight: FontWeight.bold,
    fontSize: 14,
  ),
  hintStyle: TextStyle(
    color: Bds8xColor.grey6B6B,
    fontWeight: FontWeight.normal,
    fontSize: 14,
  ),
  helperStyle: TextStyle(
    color: Bds8xColor.grey6B6B,
    fontWeight: FontWeight.normal,
    fontSize: 12,
  ),
  counterStyle: TextStyle(
    color: Bds8xColor.grey6B6B,
    fontWeight: FontWeight.normal,
    fontSize: 12,
  ),
  errorStyle: TextStyle(
    color: Bds8xColor.red4336,
    fontWeight: FontWeight.normal,
    fontSize: 12,
  ),
  prefixStyle: TextStyle(
    color: Bds8xColor.black,
    fontWeight: FontWeight.normal,
    fontSize: 14,
  ),
  suffixStyle: TextStyle(
    color: Bds8xColor.grey6B6B,
    fontWeight: FontWeight.normal,
    fontSize: 14,
  ),
  errorMaxLines: 1,
  filled: true,
  fillColor: Bds8xColor.greyEEEE,
  focusColor: Bds8xColor.greyEEEE,
  hoverColor: Bds8xColor.greyEEEE,
  isDense: true,
  contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 16),
  border: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.greyE0E0),
  ),
  focusedBorder: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.greyE0E0),
  ),
  enabledBorder: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.greyE0E0),
  ),
  disabledBorder: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.greyE0E0),
  ),
  errorBorder: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.red4336),
  ),
  focusedErrorBorder: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.red4336),
  ),
);

InputDecorationTheme tbtInputDecorationTheme = InputDecorationTheme(
  labelStyle: WowTextStyle.body.copyWith(fontWeight: FontWeight.w600),
  floatingLabelStyle: WowTextStyle.body.copyWith(fontWeight: FontWeight.w600),
  hintStyle: WowTextStyle.caption,
  helperStyle: WowTextStyle.labelLarge,
  counterStyle: WowTextStyle.labelLarge,
  errorStyle: WowTextStyle.labelLarge.copyWith(color: TBTColor.red4336),
  prefixStyle: WowTextStyle.caption,
  suffixStyle: WowTextStyle.caption,
  errorMaxLines: 1,
  filled: false,
  fillColor: TBTColor.greyF5F6,
  iconColor: TBTColor.pink4667,
  isDense: true,
  contentPadding: const EdgeInsets.symmetric(horizontal: 8, vertical: 12),
  border: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.greyF5F6),
  ),
  focusedBorder: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.greyF5F6),
  ),
  enabledBorder: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.greyF5F6),
  ),
  disabledBorder: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.greyF5F6),
  ),
  errorBorder: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.red4336),
  ),
  focusedErrorBorder: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.red4336),
  ),
);

==> wow_views-0.0.71.tar.gz: lib/common/theme/input_decoration_theme.dart <==
import 'package:flutter/material.dart';
import 'package:wow_views/common/color.dart';
import 'package:wow_views/common/text_style.dart';

const InputDecorationTheme bds8xInputDecorationTheme = InputDecorationTheme(
  labelStyle: TextStyle(
    color: Bds8xColor.black,
    fontWeight: FontWeight.bold,
    fontSize: 14,
    overflow: TextOverflow.ellipsis,
  ),
  floatingLabelStyle: TextStyle(
    color: Bds8xColor.black,
    fontWeight: FontWeight.bold,
    fontSize: 14,
  ),
  hintStyle: TextStyle(
    color: Bds8xColor.grey6B6B,
    fontWeight: FontWeight.normal,
    fontSize: 14,
  ),
  helperStyle: TextStyle(
    color: Bds8xColor.grey6B6B,
    fontWeight: FontWeight.normal,
    fontSize: 12,
  ),
  counterStyle: TextStyle(
    color: Bds8xColor.grey6B6B,
    fontWeight: FontWeight.normal,
    fontSize: 12,
  ),
  errorStyle: TextStyle(
    color: Bds8xColor.red4336,
    fontWeight: FontWeight.normal,
    fontSize: 12,
  ),
  prefixStyle: TextStyle(
    color: Bds8xColor.black,
    fontWeight: FontWeight.normal,
    fontSize: 14,
  ),
  suffixStyle: TextStyle(
    color: Bds8xColor.grey6B6B,
    fontWeight: FontWeight.normal,
    fontSize: 14,
  ),
  errorMaxLines: 1,
  filled: true,
  fillColor: Bds8xColor.greyEEEE,
  focusColor: Bds8xColor.greyEEEE,
  hoverColor: Bds8xColor.greyEEEE,
  isDense: true,
  contentPadding: EdgeInsets.symmetric(horizontal: 16, vertical: 16),
  border: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.greyE0E0),
  ),
  focusedBorder: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.greyE0E0),
  ),
  enabledBorder: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.greyE0E0),
  ),
  disabledBorder: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.greyE0E0),
  ),
  errorBorder: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.red4336),
  ),
  focusedErrorBorder: OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(15)),
    borderSide: BorderSide(color: Bds8xColor.red4336),
  ),
);

InputDecorationTheme tbtInputDecorationTheme = InputDecorationTheme(
  labelStyle: WowTextStyle.listTitle,
  floatingLabelStyle: WowTextStyle.listTitle,
  hintStyle: WowTextStyle.caption,
  helperStyle: WowTextStyle.labelLarge,
  counterStyle: WowTextStyle.labelLarge,
  errorStyle: WowTextStyle.labelLarge.copyWith(color: TBTColor.red4336),
  prefixStyle: WowTextStyle.caption,
  suffixStyle: WowTextStyle.caption,
  floatingLabelBehavior: FloatingLabelBehavior.always,
  floatingLabelAlignment: FloatingLabelAlignment.start,
  errorMaxLines: 1,
  filled: false,
  fillColor: TBTColor.greyF5F6,
  iconColor: TBTColor.greyCED9,
  prefixIconColor: TBTColor.greyCED9,
  suffixIconColor: TBTColor.greyCED9,
  isDense: true,
  contentPadding: const EdgeInsets.symmetric(horizontal: 16, vertical: 16),
  border: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.greyE0E0),
  ),
  focusedBorder: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.greyE0E0),
  ),
  enabledBorder: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.greyE0E0),
  ),
  disabledBorder: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.greyE0E0),
  ),
  errorBorder: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.red4336),
  ),
  focusedErrorBorder: const OutlineInputBorder(
    borderRadius: BorderRadius.all(Radius.circular(10)),
    borderSide: BorderSide(color: TBTColor.red4336),
  ),
);
